package com.softbankrobotics.pepperhelloworld;

import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;

import com.aldebaran.qi.Future;
import com.aldebaran.qi.sdk.QiContext;
import com.aldebaran.qi.sdk.QiSDK;
import com.aldebaran.qi.sdk.RobotLifecycleCallbacks;
import com.aldebaran.qi.sdk.builder.GoToBuilder;
import com.aldebaran.qi.sdk.builder.SayBuilder;
import com.aldebaran.qi.sdk.builder.TransformBuilder;
import com.aldebaran.qi.sdk.design.activity.RobotActivity;
import com.aldebaran.qi.sdk.object.actuation.Frame;
import com.aldebaran.qi.sdk.object.actuation.FreeFrame;
import com.aldebaran.qi.sdk.object.actuation.GoTo;
import com.aldebaran.qi.sdk.object.conversation.Say;
import com.aldebaran.qi.sdk.object.geometry.Transform;

public class GoToActivity extends RobotActivity implements RobotLifecycleCallbacks {

    private Future<Void> goToFuture;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_go_to);

        QiSDK.register(this,this);
    }

    @Override
    protected void onDestroy() {

        QiSDK.unregister(this,this);

        super.onDestroy();
    }

    @Override
    public void onRobotFocusGained(QiContext qiContext) {

        Frame robotFrame = qiContext.getActuation().robotFrame();

        Transform transform = TransformBuilder.create().fromXTranslation(3);

        FreeFrame targetFrame = qiContext.getMapping().makeFreeFrame();
        targetFrame.update(robotFrame,transform,System.currentTimeMillis());

        GoTo goTo = GoToBuilder.with(qiContext)
                .withFrame(targetFrame.frame())
                .build();

        goToFuture = goTo.async().run();

        goToFuture.thenConsume(voidFuture -> {
            if (goToFuture.isSuccess()) {
                Log.i("MyTag", "The hello future has ended with success");
                Say say = SayBuilder.with(qiContext)
                        .withText("はい、着きました")
                        .build();
                say.run();
            } else if (goToFuture.isCancelled()) {
                Log.i("MyTag", "The hello future has been cancelled");
            } else if (goToFuture.hasError()) {
                Log.i("MyTag", "The hello future has finished with an error; "
                        + goToFuture.getErrorMessage());
                Say say = SayBuilder.with(qiContext)
                        .withText("あれ、たどり着けません")
                        .build();
                say.run();
            }
        });


    }

    @Override
    public void onRobotFocusLost() {

    }

    @Override
    public void onRobotFocusRefused(String reason) {

    }
}
